@@ -174,3 +174,56 @@ class ReturnQuantityType(object):
         (ENTIRE, "整单退"),
         (NONE, "无退货")
     )
+
+
+class ShippingMethod(object):
+    # 普通快递
+    EXPRESS = 'express'
+    # 自提
+    SELF_SERVICE = 'self_service'
+    # 闪送
+    FLASH_DELIVERY = 'flash_delivery'
+    # 自费闪送
+    SELF_FLASH = 'self_flash'
+
+    CHOICES = (
+        (EXPRESS, "快递发货"),
+        (SELF_SERVICE, "到店自提"),
+        (FLASH_DELIVERY, "闪送"),
+        (SELF_FLASH, "自费闪送"),
+    )
+
+
+class ShippingMethodInt:
+    ''' 配送方式的 int 编码 '''
+
+    # 自提
+    SELF_SERVICE_INT = 1
+    # 快递
+    EXPRESS_INT = 2
+    # 自费闪送
+    SELF_FLASH_INT = 4
+    # 闪送
+    FLASH_DELIVERY_INT = 8
+
+    str2int_map = {
+        ShippingMethod.EXPRESS: EXPRESS_INT,
+        ShippingMethod.SELF_SERVICE: SELF_SERVICE_INT,
+        ShippingMethod.SELF_FLASH: SELF_FLASH_INT,
+        ShippingMethod.FLASH_DELIVERY: FLASH_DELIVERY_INT
+    }
+
+    int2str_map = {v: k for k, v in str2int_map.items()}
+
+    @classmethod
+    def str2int(cls, shipping_method_str):
+        return cls.str2int_map[shipping_method_str]
+
+    @classmethod
+    def int2str(cls, shipping_method_int):
+        return cls.int2str_map[shipping_method_int]
+
+    @classmethod
+    def total_int_2_strs(cls, total_int):
+        ''' 将某个包含多种配送方式的 int 值转为多个 shipping_method '''
+        return [v for k, v in cls.int2str_map.items() if k & total_int]
