@@ -108,3 +108,8 @@ class AfsLineGenerateFrom:
         (VIRTUAL, "虚拟订单数据"),
         (ORIGIN, "创建售后前的订单(或虚拟订单)数据"),
     )
+
+
+class AfsVersionConst:
+    V2 = "V2"
+    V3 = "V3"
